@@ -4,65 +4,66 @@ require 5.006;
 
 use warnings;
 use strict;
+use utf8;
 use Carp;
 
-use version; our $VERSION = '0.1.4_2';
+use version; our $VERSION = '0.20';
 
 use Encode;
 use LWP::UserAgent;
 use URI::Escape;
 
 my %_tdfk_dict = qw/
-̳ƻ ۤäɤ
-Ŀ ꤱ
-긩 Ƥ
-ܾ븩 ߤ䤮
-ĸ 
- ޤ
-ʡ縩 դޤ
-븩 Ф餭
-ڸ Ȥ
-ϸ ޤ
-̸ ޤ
-ո Ф
- Ȥ礦
- ʤ櫓
-ٻ Ȥޤ
-㸩 ˤ
- 櫓
-ʡ温 դ
- ޤʤ
-Ĺ ʤΤ
-츩 դ
-Ų 
-θ 
-Ÿ ߤ
-츩 
- 礦Ȥ
- 
-ʼ˸ Ҥ礦
-ɸ ʤ餱
-²λ 狼ޤ
-Ļ踩 ȤäȤꤱ
-纬 ޤͤ
- ޤ
-縩 Ҥޤ
- ޤ
-縩 Ȥޤ
- 櫓
-ɲ Ҥᤱ
-θ 
-ʡ դ
-츩 
-Ĺ긩 ʤ
-ܸ ޤȤ
-ʬ 
-ܺ긩 ߤ䤶
-縩 ޤ
-츩 ʤ櫓
+北海道 ほっかいどう
+青森県 あおもりけん
+岩手県 いわてけん
+宮城県 みやぎけん
+秋田県 あきたけん
+山形県 やまがたけん
+福島県 ふくしまけん
+茨城県 いばらきけん
+栃木県 とちぎけん
+群馬県 ぐんまけん
+埼玉県 さいたまけん
+千葉県 ちばけん
+東京都 とうきょうと
+神奈川県 かながわけん
+富山県 とやまけん
+新潟県 にいがたけん
+石川県 いしかわけん
+福井県 ふくいけん
+山梨県 やまなしけん
+長野県 ながのけん
+岐阜県 ぎふけん
+静岡県 しずおかけん
+愛知県 あいちけん
+三重県 みえけん
+滋賀県 しがけん
+京都府 きょうとふ
+大阪府 おおさかふ
+兵庫県 ひょうごけん
+奈良県 ならけん
+和歌山県 わかやまけん
+鳥取県 とっとりけん
+島根県 しまねけん
+岡山県 おかやまけん
+広島県 ひろしまけん
+山口県 やまぐちけん
+徳島県 とくしまけん
+香川県 かがわけん
+愛媛県 えひめけん
+高知県 こうちけん
+福岡県 ふくおかけん
+佐賀県 さがけん
+長崎県 ながさきけん
+熊本県 くまもとけん
+大分県 おおいたけん
+宮崎県 みやざきけん
+鹿児島県 かごしまけん
+沖縄県 おきなわけん
 /;
 
-my $search_url_tpl = 'http://search.map.yahoo.co.jp/search?p=%s&ei=euc-jp';
+my $search_url_tpl = 'http://search.map.yahoo.co.jp/search?p=%s&ei=UTF-8';
 my $kana_url_tpl   = 'http://map.yahoo.co.jp/address?ac=%s';
 
 
@@ -92,11 +93,11 @@ sub _do_freeword_search{
     my $self = shift;
     my $word = shift;
 
-    my $url = sprintf($search_url_tpl, uri_escape($word));
+    my $url = sprintf $search_url_tpl, uri_escape( encode_utf8 $word );
 
     my $ua  = $self->{ua};
     my $res = $ua->get($url);
-    return $res->content();
+    return $res->decoded_content;
 }
 
 
@@ -126,7 +127,7 @@ sub _correct_choaza{
     $corrected_address =~ s/[0-9]+$//;
 
     # chop chome
-    $corrected_address =~ s/[0-9]+$//;
+    $corrected_address =~ s/[0-9]+丁目$//;
 
     return $corrected_address;
 }
@@ -168,8 +169,7 @@ sub _get_kana_dict{
 
     my $ua  = $self->{ua};
     my $res = $ua->get($url);
-    my $c = $res->content();
-    Encode::from_to($c, 'utf8', 'eucJP');
+    my $c = $res->decoded_content;
     my %ret = ();
     while ($c =~ m{<ruby[^>]*>.*?<a[^>]*>(.+?)</a>.*?<rt>(.+?)</rt>.*?</ruby>}g) {
         my ($kanji, $kana) = $self->_strip_tag($1, $2);
@@ -224,7 +224,7 @@ sub search{
 1; # Magic true value required at end of module
 __END__
 
-=encoding euc-jp
+=encoding utf-8
 
 =head1 NAME
 
@@ -235,11 +235,11 @@ WWW::YahooJapan::KanaAddress - translating the address in Japan into kana.
     use WWW::YahooJapan::KanaAddress;
 
     my $yahoo = WWW::YahooJapan::KanaAddress->new();
-    print $yahoo->search('', 'Į', 'Ļ'), "\n";
+    print $yahoo->search('山梨県', '鰍沢町', '鳥屋'), "\n";
 
 results:
 
-    ޤʤ󤫤礦Ȥ
+    やまなしけんかじかざわちょうとや
 
 =head1 DESCRIPTION
 
@@ -255,29 +255,29 @@ a constructor. You can set a LWP::UserAgent object if you want.
 
 =item my ($kana_ken, $kana_shiku, $kana_choaza) = $yahoo->search($ken, $shiku, $choaza);
 
-search kana by Yahoo!Japan Maps. The arguments and return values must be encoded to euc-jp. You can't use unicode string.
+search kana by Yahoo!Japan Maps. The arguments and return values must be unicode strings. ( You can no longer use euc-jp encoded strings from 0.20. )
 
 =over 2
 
 =item $ken
 
-Prefecture in Japan, should be ended with '' or 'ƻ' or '' or ''.
+Prefecture in Japan, should be ended with '都' or '道' or '府' or '県'.
 
 =item $shiku
 
-Name of city and district, should be ended with '' or '' or 'Į' or '¼'.
+Name of city and district, should be ended with '市' or '区' or '町' or '村'.
 
 =item $choaza
 
-The rest of the string of address. It might contain 'Į' and ''.
+The rest of the string of address. It might contain '町' and '字'.
 
 =back
 
 You can use a vague address to some degree. For example: 
 
-    print $yahoo->search('븩', 'ζ', 'Į'), "\n";
-    print $yahoo->search('븩', 'ζ', 'Į'), "\n";
-    print $yahoo->search('븩', 'ε', 'Į'), "\n";
+    print $yahoo->search('茨城県', '龍ヶ崎市', '米町'), "\n";
+    print $yahoo->search('茨城県', '龍崎市', '米町'), "\n";
+    print $yahoo->search('茨城県', '竜が崎市', '米町'), "\n";
 
 These sentences output the same result. This is a function of Yahoo!Japan Maps.
 
@@ -309,3 +309,11 @@ C<hiratara@cpan.org>, or through the web interface at L<http://rt.cpan.org>.
 =head1 AUTHOR
 
 Masahiro Honma  C<< <hiratara@cpan.org> >>
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
+
